@@ -50,7 +50,7 @@ def makeRequest(pubkey, pkey, serv_host, auto=False):
     if auto:
         c = 'n'
     else:
-        c = raw_input(_("Enter the certificate data manually? y/[n]: "))
+        c = input(_("Enter the certificate data manually? y/[n]: "))
     # Get HostName
     host_name = socket.getfqdn()
     list_host_name = host_name.split('.')
@@ -69,20 +69,20 @@ def makeRequest(pubkey, pkey, serv_host, auto=False):
         # list_host_name[len(list_host_name)-1]+"@"+serv_host
         # else:
         # host_name = socket.getfqdn()
-        _CN = raw_input(_('Host Name [%s]: ') % result_host_name)
+        _CN = input(_('Host Name [%s]: ') % result_host_name)
         name.CN = _CN or result_host_name
 
-        _OU = raw_input(_('User Name [%s]: ') % username)
+        _OU = input(_('User Name [%s]: ') % username)
         name.OU = _OU or username
-        _O = raw_input(_('Organization Name: '))
+        _O = input(_('Organization Name: '))
         name.O = _O or ""
 
-        _L = raw_input(_('Network address (hostname or IP) [%s]: ')
+        _L = input(_('Network address (hostname or IP) [%s]: ')
                            % host_name)
         name.L = _L or ""
-        _ST = raw_input(_('City: '))
+        _ST = input(_('City: '))
         name.ST = _ST or ""
-        _C = raw_input(_('Country (2 characters): [%s]') % lang)
+        _C = input(_('Country (2 characters): [%s]') % lang)
         name.C = _C or lang
 
     else:
